# Stellarator-Database
Includes the functions required to upload DESC or VMEC results to the stellarator database. You can access the database [here](https://ye2698.mycpanel.princeton.edu/).

This is still a work in progress.

## Building conda environment
```bash
conda create --name db
conda activate db
pip install -r requirements.txt
```
